@@ -18,16 +18,23 @@ def _percentile(a, q, interpolation="linear"):
     if isinstance(q, Iterator):
         q = list(q)
     if a.dtype.name == "category":
-        result = np.percentile(a.codes, q, interpolation=interpolation)
+        result = np.percentile(a.cat.codes, q, interpolation=interpolation)
         import pandas as pd
 
-        return pd.Categorical.from_codes(result, a.categories, a.ordered), n
+        return pd.Categorical.from_codes(result, a.dtype.categories, a.dtype.ordered), n
+    if type(a.dtype).__name__ == "DatetimeTZDtype":
+        import pandas as pd
+
+        if isinstance(a, (pd.Series, pd.Index)):
+            a = a.values
+
     if np.issubdtype(a.dtype, np.datetime64):
-        a2 = a.astype("i8")
-        result = np.percentile(a2, q, interpolation=interpolation).astype(a.dtype)
+        values = a
+        a2 = values.view("i8")
+        result = np.percentile(a2, q, interpolation=interpolation).astype(values.dtype)
         if q[0] == 0:
             # https://github.com/dask/dask/issues/6864
-            result[0] = min(result[0], a.min())
+            result[0] = min(result[0], values.min())
         return result, n
     if not np.issubdtype(a.dtype, np.number):
         interpolation = "nearest"
@@ -84,6 +91,8 @@ def percentile(a, q, interpolation="linear", method="default"):
     --------
     numpy.percentile : Numpy's equivalent Percentile function
     """
+    from dask.dataframe.dispatch import _percentile
+
     from .utils import array_safe, meta_from_array
 
     if not a.ndim == 1:
