@@ -33,14 +33,7 @@ from .core import (
 from .creation import arange, diag, empty, indices, tri
 from .einsumfuncs import einsum  # noqa
 from .ufunc import multiply, sqrt
-from .utils import (
-    array_safe,
-    asarray_safe,
-    meta_from_array,
-    safe_wraps,
-    validate_axis,
-    zeros_like_safe,
-)
+from .utils import array_safe, asarray_safe, meta_from_array, safe_wraps, validate_axis
 from .wrap import ones
 
 # save built-in for histogram functions which use range as a kwarg.
@@ -699,7 +692,7 @@ def _bincount_agg(bincounts, dtype, **kwargs):
         return bincounts
 
     n = max(map(len, bincounts))
-    out = zeros_like_safe(bincounts[0], shape=n, dtype=dtype)
+    out = np.zeros_like(bincounts[0], shape=n, dtype=dtype)
     for b in bincounts:
         out[: len(b)] += b
     return out
@@ -2363,7 +2356,7 @@ def tril(m, k=0):
         *m.shape[-2:], k=k, dtype=bool, chunks=m.chunks[-2:], like=meta_from_array(m)
     )
 
-    return where(mask, m, zeros_like_safe(m, shape=(1,)))
+    return where(mask, m, np.zeros_like(m, shape=(1,)))
 
 
 @derived_from(np)
@@ -2377,7 +2370,7 @@ def triu(m, k=0):
         like=meta_from_array(m),
     )
 
-    return where(mask, zeros_like_safe(m, shape=(1,)), m)
+    return where(mask, np.zeros_like(m, shape=(1,)), m)
 
 
 @derived_from(np)
