@@ -18,6 +18,8 @@ from dask.array.utils import assert_eq
 def test__parse_gufunc_signature():
     assert_equal(_parse_gufunc_signature("(x)->()"), ([("x",)], ()))
     assert_equal(_parse_gufunc_signature("(x,y)->()"), ([("x", "y")], ()))
+    # whitespace
+    assert_equal(_parse_gufunc_signature("  (x, y) ->()"), ([("x", "y")], ()))
     assert_equal(_parse_gufunc_signature("(x),(y)->()"), ([("x",), ("y",)], ()))
     assert_equal(_parse_gufunc_signature("(x)->(y)"), ([("x",)], ("y",)))
     assert_equal(_parse_gufunc_signature("(x)->(y),()"), ([("x",)], [("y",), ()]))
@@ -330,6 +332,19 @@ def test_gufunc_mixed_inputs_vectorize():
     assert_eq(x, np.full((8, 3), 10, dtype=int))
 
 
+def test_gufunc_vectorize_whitespace():
+    # Regression test for https://github.com/dask/dask/issues/7972
+
+    def foo(x, y):
+        return (x + y).sum(axis=1)
+
+    a = da.ones((8, 3, 5), chunks=(2, 3, 5), dtype=int)
+    b = np.ones(5, dtype=int)
+    x = apply_gufunc(foo, "(m, n),(n)->(m)", a, b, vectorize=True)
+
+    assert_eq(x, np.full((8, 3), 10, dtype=int))
+
+
 def test_gufunc():
     x = da.random.normal(size=(10, 5), chunks=(2, 5))
 
