@@ -499,14 +499,26 @@ def _link(token, result):
     return None
 
 
-def _df_to_bag(df, index=False):
+def _df_to_bag(df, index=False, format="tuple"):
     if isinstance(df, pd.DataFrame):
-        return list(map(tuple, df.itertuples(index)))
+        if format == "tuple":
+            return list(map(tuple, df.itertuples(index)))
+        elif format == "dict":
+            if index:
+                return [
+                    {**{"index": idx}, **values}
+                    for values, idx in zip(df.to_dict("records"), df.index)
+                ]
+            else:
+                return df.to_dict(orient="records")
     elif isinstance(df, pd.Series):
-        return list(df.iteritems()) if index else list(df)
+        if format == "tuple":
+            return list(df.iteritems()) if index else list(df)
+        elif format == "dict":
+            return df.to_frame().to_dict(orient="records")
 
 
-def to_bag(df, index=False):
+def to_bag(df, index=False, format="tuple"):
     """Create Dask Bag from a Dask DataFrame
 
     Parameters
@@ -514,6 +526,8 @@ def to_bag(df, index=False):
     index : bool, optional
         If True, the elements are tuples of ``(index, value)``, otherwise
         they're just the ``value``.  Default is False.
+    format : {"tuple", "dict"},optional
+            Whether to return a bag of tuples or dictionaries.
 
     Examples
     --------
@@ -523,9 +537,9 @@ def to_bag(df, index=False):
 
     if not isinstance(df, (DataFrame, Series)):
         raise TypeError("df must be either DataFrame or Series")
-    name = "to_bag-" + tokenize(df, index)
+    name = "to_bag-" + tokenize(df, index, format)
     dsk = dict(
-        ((name, i), (_df_to_bag, block, index))
+        ((name, i), (_df_to_bag, block, index, format))
         for (i, block) in enumerate(df.__dask_keys__())
     )
     dsk.update(df.__dask_optimize__(df.__dask_graph__(), df.__dask_keys__()))
