@@ -104,6 +104,7 @@ def read_parquet(
     storage_options=None,
     engine="auto",
     gather_statistics=None,
+    ignore_metadata_file=False,
     split_row_groups=None,
     read_from_paths=None,
     chunksize=None,
@@ -176,6 +177,8 @@ def read_parquet(
         this will only be done if the _metadata file is available. Otherwise,
         statistics will only be gathered if True, because the footer of
         every file will be parsed (which is very slow on some systems).
+    ignore_metadata_file : bool, default False
+        Whether to ignore the global ``_metadata`` file (when one is present).
     split_row_groups : bool or int, default None
         Default is True if a _metadata file is available or if
         the dataset is composed of a single file (otherwise defult is False).
@@ -259,6 +262,7 @@ def read_parquet(
             storage_options=storage_options,
             engine=engine,
             gather_statistics=gather_statistics,
+            ignore_metadata_file=ignore_metadata_file,
             split_row_groups=split_row_groups,
             read_from_paths=read_from_paths,
             chunksize=chunksize,
@@ -279,6 +283,7 @@ def read_parquet(
         storage_options,
         engine,
         gather_statistics,
+        ignore_metadata_file,
         split_row_groups,
         read_from_paths,
         chunksize,
@@ -321,6 +326,7 @@ def read_parquet(
         read_from_paths=read_from_paths,
         chunksize=chunksize,
         aggregate_files=aggregate_files,
+        ignore_metadata_file=ignore_metadata_file,
         **kwargs,
     )
 
