@@ -22,6 +22,7 @@ from .base import clone_key, flatten, is_dask_collection
 from .core import keys_in_tasks, reverse_dict
 from .utils import _deprecated, ensure_dict, key_split, stringify
 from .utils_test import add, inc  # noqa: F401
+from .widgets import get_template
 
 
 def compute_layer_dependencies(layers):
@@ -467,26 +468,6 @@ class Layer(collections.abc.Mapping):
         return obj
 
     def _repr_html_(self, layer_index="", highlevelgraph_key=""):
-        unmaterialized_layer_icon = """
-            <svg width="24" height="24" viewBox="0 0 32 32" fill="none"
-                xmlns="http://www.w3.org/2000/svg" style="position: absolute;">
-                <circle cx="16" cy="16" r="14"
-                    style="stroke: var(--jp-ui-font-color2, #1D1D1D); fill: var(--jp-layout-color1, #F2F2F2);"
-                    stroke-width="2" />
-            </svg>
-        """
-        materialized_layer_icon = """
-            <svg width="24" height="24" viewBox="0 0 32 32" fill="none"
-                xmlns="http://www.w3.org/2000/svg" style="position: absolute;">
-                <circle cx="16" cy="16" r="14" fill="#8F8F8F"
-                    style="stroke: var(--jp-ui-font-color2, #1D1D1D);" stroke-width="2"/>
-            </svg>
-        """
-        if self.is_materialized():
-            layer_icon = materialized_layer_icon
-        else:
-            layer_icon = unmaterialized_layer_icon
-
         if highlevelgraph_key != "":
             shortname = key_split(highlevelgraph_key)
         elif hasattr(self, "name"):
@@ -503,26 +484,16 @@ class Layer(collections.abc.Mapping):
             if chunks:
                 from .array.svg import svg
 
-                svg_repr = "<br />" + svg(chunks)
+                svg_repr = svg(chunks)
 
-        info = self.layer_info_dict()
-        layer_info_table = html_from_dict(info)
-        html = f"""
-            <div style="">
-                {layer_icon}
-                <details style="margin-left: 32px;">
-                    <summary style="margin-bottom: 10px; margin-top: 10px;">
-                        <h4 style="display: inline;">Layer{layer_index}: {shortname}</h4>
-                    </summary>
-                    <p style="color: var(--jp-ui-font-color2, #5D5851); margin: -0.25em 0px 0px 0px;">
-                        {highlevelgraph_key}
-                    </p>
-                    {svg_repr}
-                    {layer_info_table}
-                </details>
-            </div>
-            """
-        return html
+        return get_template("highlevelgraph_layer.html.j2").render(
+            materialized=self.is_materialized(),
+            shortname=shortname,
+            layer_index=layer_index,
+            highlevelgraph_key=highlevelgraph_key,
+            info=self.layer_info_dict(),
+            svg_repr=svg_repr,
+        )
 
     def layer_info_dict(self):
         info = {
@@ -870,6 +841,43 @@ class HighLevelGraph(Mapping):
         return cls(layers, dependencies)
 
     def visualize(self, filename="dask-hlg.svg", format=None, **kwargs):
+        """
+        Visualize this dask high level graph.
+
+        Requires ``graphviz`` to be installed.
+
+        Parameters
+        ----------
+        filename : str or None, optional
+            The name of the file to write to disk. If the provided `filename`
+            doesn't include an extension, '.png' will be used by default.
+            If `filename` is None, no file will be written, and the graph is
+            rendered in the Jupyter notebook only.
+        format : {'png', 'pdf', 'dot', 'svg', 'jpeg', 'jpg'}, optional
+            Format in which to write output file. Default is 'svg'.
+        color : {None, 'layer_type'}, optional (default: None)
+            Options to color nodes.
+            - None, no colors.
+            - layer_type, color nodes based on the layer type.
+        **kwargs
+           Additional keyword arguments to forward to ``to_graphviz``.
+
+        Examples
+        --------
+        >>> x.dask.visualize(filename='dask.svg')  # doctest: +SKIP
+        >>> x.dask.visualize(filename='dask.svg', color='layer_type')  # doctest: +SKIP
+
+        Returns
+        -------
+        result : IPython.diplay.Image, IPython.display.SVG, or None
+            See dask.dot.dot_graph for more information.
+
+        See Also
+        --------
+        dask.dot.dot_graph
+        dask.base.visualize # low level variant
+        """
+
         from .dot import graphviz_to_file
 
         g = to_graphviz(self, **kwargs)
@@ -1125,76 +1133,11 @@ class HighLevelGraph(Mapping):
         return representation
 
     def _repr_html_(self):
-        highlevelgraph_info = f"{type(self).__name__} with {len(self.layers)} layers."
-        highlevelgraph_icon = """
-            <svg width="76" height="71" viewBox="0 0 76 71" fill="none" xmlns="http://www.w3.org/2000/svg">
-                <circle cx="61.5" cy="36.5" r="13.5"
-                    style="stroke: var(--jp-ui-font-color2, #1D1D1D); fill: var(--jp-layout-color1, #F2F2F2);"
-                    stroke-width="2"/>
-                <circle cx="14.5" cy="14.5" r="13.5"
-                    style="stroke: var(--jp-ui-font-color2, #1D1D1D); fill: var(--jp-layout-color1, #F2F2F2);"
-                    stroke-width="2"/>
-                <circle cx="14.5" cy="56.5" r="13.5"
-                    style="stroke: var(--jp-ui-font-color2, #1D1D1D); fill: var(--jp-layout-color1, #F2F2F2);"
-                    stroke-width="2"/>
-                <path d="M28 16L30.5 16C33.2614 16 35.5 18.2386 35.5 21L35.5 32.0001C35.5 34.7615 37.7386
-                    37.0001 40.5 37.0001L43 37.0001" style="stroke: var(--jp-ui-font-color2, #1D1D1D);"
-                    stroke-width="1.5"/>
-                <path d="M40.5 37L40.5 37.75L40.5 37.75L40.5 37ZM35.5 42L36.25 42L35.5 42ZM35.5 52L34.75
-                    52L35.5 52ZM30.5 57L30.5 57.75L30.5 57ZM41.5001 36.25L40.5 36.25L40.5 37.75L41.5001
-                    37.75L41.5001 36.25ZM34.75 42L34.75 52L36.25 52L36.25 42L34.75 42ZM30.5 56.25L28.0001
-                    56.25L28.0001 57.75L30.5 57.75L30.5 56.25ZM34.75 52C34.75 54.3472 32.8472 56.25 30.5
-                    56.25L30.5 57.75C33.6756 57.75 36.25 55.1756 36.25 52L34.75 52ZM40.5 36.25C37.3244 36.25
-                    34.75 38.8243 34.75 42L36.25 42C36.25 39.6528 38.1528 37.75 40.5 37.75L40.5 36.25Z"
-                    style="fill: var(--jp-ui-font-color2, #1D1D1D);"/>
-                <circle cx="28" cy="16" r="2.25" fill="#E5E5E5"
-                    style="stroke: var(--jp-ui-font-color2, #1D1D1D);" stroke-width="1.5"/>
-                <circle cx="28" cy="57" r="2.25" fill="#E5E5E5"
-                    style="stroke: var(--jp-ui-font-color2, #1D1D1D);" stroke-width="1.5"/>
-                <path d="M45.25 36.567C45.5833 36.7594 45.5833 37.2406 45.25 37.433L42.25 39.1651C41.9167
-                    39.3575 41.5 39.117 41.5 38.7321V35.2679C41.5 34.883 41.9167 34.6425 42.25 34.8349L45.25
-                    36.567Z" style="fill: var(--jp-ui-font-color2, #1D1D1D);"/>
-            </svg>
-        """
-        layers_html = ""
-        for i, key in enumerate(self._toposort_layers()):
-            layer = self.layers[key]
-            layers_html += layer._repr_html_(
-                layer_index=f" {i}", highlevelgraph_key=key
-            )
-
-        html = f"""
-            <div>
-                <div>
-                    <div style="width: 52px; height: 52px; position: absolute;">
-                        {highlevelgraph_icon}
-                    </div>
-                    <div style="margin-left: 64px;">
-                        <h3 style="margin-bottom: 0px;">HighLevelGraph</h3>
-                        <p style="color: var(--jp-ui-font-color2, #5D5851); margin-bottom:0px;">
-                            {highlevelgraph_info}
-                        </p>
-                        {layers_html}
-                    </div>
-                </div>
-            </div>
-        """
-        return html
-
-
-def html_from_dict(info):
-    html = """<table style="width: 100%;">"""
-    suffix = """</table>"""
-    for key, val in info.items():
-        table_row = f"""
-          <tr>
-            <th style="text-align: left; width: 150px;">{key}</th>
-            <td style="text-align: left;">{val}</td>
-          </tr>
-        """
-        html += table_row
-    html += suffix
-    return html
+        return get_template("highlevelgraph.html.j2").render(
+            type=type(self).__name__,
+            layers=self.layers,
+            toposort=self._toposort_layers(),
+        )
 
 
 def to_graphviz(
@@ -1228,18 +1171,34 @@ def to_graphviz(
     for layer in hg.dependencies:
         n_tasks[layer] = len(hg.layers[layer])
 
-    mn = min(n_tasks.values())
-    mx = max(n_tasks.values())
+    min_tasks = min(n_tasks.values())
+    max_tasks = max(n_tasks.values())
 
     cache = {}
 
+    color = kwargs.get("color")
+    if color == "layer_type":
+        layer_colors = {
+            "DataFrameIOLayer": ["#CCC7F9", False],  # purple
+            "ShuffleLayer": ["#F9CCC7", False],  # rose
+            "SimpleShuffleLayer": ["#F9CCC7", False],  # rose
+            "ArrayOverlayLayer": ["#FFD9F2", False],  # pink
+            "BroadcastJoinLayer": ["#D9F2FF", False],  # blue
+            "Blockwise": ["#D9FFE6", False],  # green
+            "BlockwiseLayer": ["#D9FFE6", False],  # green
+            "BlockwiseCreateArray": ["#D9FFE6", False],  # green
+            "MaterializedLayer": ["#DBDEE5", False],  # gray
+        }
+
     for layer in hg.dependencies:
         layer_name = name(layer)
         attrs = data_attributes.get(layer, {})
 
         node_label = label(layer, cache=cache)
         node_size = (
-            20 if mx == mn else int(20 + ((n_tasks[layer] - mn) / (mx - mn)) * 20)
+            20
+            if max_tasks == min_tasks
+            else int(20 + ((n_tasks[layer] - min_tasks) / (max_tasks - min_tasks)) * 20)
         )
 
         layer_type = str(type(hg.layers[layer]).__name__)
@@ -1271,6 +1230,13 @@ def to_graphviz(
         attrs.setdefault("fontsize", str(node_size))
         attrs.setdefault("tooltip", str(node_tooltips))
 
+        if color == "layer_type":
+            node_color = layer_colors.get(layer_type)[0]
+            layer_colors.get(layer_type)[1] = True
+
+            attrs.setdefault("fillcolor", str(node_color))
+            attrs.setdefault("style", "filled")
+
         g.node(layer_name, **attrs)
 
     for layer, deps in hg.dependencies.items():
@@ -1278,6 +1244,28 @@ def to_graphviz(
         for dep in deps:
             dep_name = name(dep)
             g.edge(dep_name, layer_name)
+
+    if color == "layer_type":
+        legend_title = "Key"
+
+        legend_label = (
+            '<<TABLE BORDER="0" CELLBORDER="1" CELLSPACING="0" CELLPADDING="5">'
+            "<TR><TD><B>Legend: Layer types</B></TD></TR>"
+        )
+
+        for layer_type, color in layer_colors.items():
+            if color[1]:
+                legend_label += f'<TR><TD BGCOLOR="{color[0]}">{layer_type}</TD></TR>'
+
+        legend_label += "</TABLE>>"
+
+        attrs = data_attributes.get(legend_title, {})
+        attrs.setdefault("label", str(legend_label))
+        attrs.setdefault("fontsize", "20")
+        attrs.setdefault("margin", "0")
+
+        g.node(legend_title, **attrs)
+
     return g
 
 
