@@ -351,7 +351,7 @@ def test_local_parents_of_reduction(abcde):
     b1, b2, b3 = [b + i for i in "123"]
     c1, c2, c3 = [c + i for i in "123"]
 
-    expected = [a3, b3, c3, a2, a1, b2, b1, c2, c1]
+    expected = [a3, a2, a1, b3, b2, b1, c3, c2, c1]
 
     log = []
 
